@@ -763,10 +763,11 @@ class CameraPropertyObservableObject(TypedDict):
     new_state: Any
 
 
+@runtime_checkable
 class CameraDevice(Protocol):
     id: str
     plugin_id: str
-    native_id: Optional[str] = None
+    native_id: Optional[str]
     connected: bool
     disabled: bool
     name: str
@@ -950,17 +951,6 @@ class CameraConfig(BaseCameraConfig):
     sources: list[CameraConfigInputSettings]
 
 
-# events and callbacks
-CameraSelectedCallback = Union[
-    Callable[[CameraDevice, CameraExtension], None],
-    Callable[[CameraDevice, CameraExtension], Coroutine[None, None, None]],
-]
-CameraDeselectedCallback = Union[
-    Callable[[str, CameraExtension], None],
-    Callable[[str, CameraExtension], Coroutine[None, None, None]],
-]
-
-
 # CoreManager
 class FfmpegArgs(TypedDict):
     hwaccel: str
@@ -969,6 +959,18 @@ class FfmpegArgs(TypedDict):
     threads: str
 
 
+class DBSystem(TypedDict):
+    serverAddresses: list[str]
+
+
+SystemUpdateCallback = Union[
+    Callable[[DBSystem], None],
+    Callable[[DBSystem], Coroutine[None, None, None]],
+]
+
+CoreManagerEventType = Literal["systemUpdated",]
+
+
 @runtime_checkable
 class CoreManager(Protocol):
     async def get_ffmpeg_path(self) -> str: ...
@@ -976,8 +978,27 @@ class CoreManager(Protocol):
     async def get_ice_servers(self) -> list[IceServer]: ...
     async def get_server_addresses(self) -> list[str]: ...
 
+    def on(self, event: Literal["systemUpdated"], listener: SystemUpdateCallback) -> "CoreManager": ...
+
+    def once(self, event: Literal["systemUpdated"], listener: SystemUpdateCallback) -> "CoreManager": ...
+
+    def remove_listener(
+        self, event: Literal["systemUpdated"], listener: SystemUpdateCallback
+    ) -> "DeviceManager": ...
+
+    def remove_all_listeners(self, event: Optional[CoreManagerEventType] = None) -> "CoreManager": ...
+
 
 # DeviceManager
+CameraSelectedCallback = Union[
+    Callable[[CameraDevice, CameraExtension], None],
+    Callable[[CameraDevice, CameraExtension], Coroutine[None, None, None]],
+]
+CameraDeselectedCallback = Union[
+    Callable[[str, CameraExtension], None],
+    Callable[[str, CameraExtension], Coroutine[None, None, None]],
+]
+
 DeviceManagerEventType = Literal[
     "cameraSelected",
     "cameraDeselected",
@@ -988,7 +1009,7 @@ DeviceManagerEventType = Literal[
 class DeviceManager(Protocol):
     async def get_camera_by_id(self, id: str) -> Optional[CameraDevice]: ...
     async def get_camera_by_name(self, name: str) -> Optional[CameraDevice]: ...
-    async def create_camera(self, config: CameraConfig) -> CameraDevice: ...
+    async def create_camera(self, camera_config: CameraConfig) -> CameraDevice: ...
     async def remove_camera_by_id(self, id: str) -> None: ...
     async def remove_camera_by_name(self, name: str) -> None: ...
 
